@@ -1467,6 +1467,18 @@ defmodule NimbleParsecTest do
     end
   end
 
+  describe "bytes/2 combinator" do
+    defparsec :parse_bytes, bytes(3)
+
+    test "succeeds if input has sufficient bytes" do
+      assert parse_bytes("abc") == {:ok, ["abc"], "", %{}, {1, 0}, 3}
+    end
+
+    test "fails if input has insufficient bytes" do
+      assert parse_bytes("ab") == {:error, "expected 3 bytes", "ab", %{}, {1, 0}, 0}
+    end
+  end
+
   describe "continuing parser" do
     defparsecp :digits, [?0..?9] |> ascii_char() |> times(min: 1) |> label("digits")
     defparsecp :chars, [?a..?z] |> ascii_char() |> times(min: 1) |> label("chars")
@@ -1488,8 +1500,8 @@ defmodule NimbleParsecTest do
     end
   end
 
-  defp location(_rest, args, %{} = context, line, offset, tag) do
-    {[{tag, args, line, offset}], context}
+  defp location(rest, args, %{} = context, line, offset, tag) do
+    {rest, [{tag, args, line, offset}], context}
   end
 
   defp bound?(document) do
@@ -1542,6 +1554,6 @@ defmodule NimbleParsecTest do
   defp private_join_and_wrap(rest, args, %{} = context, {line, line_offset}, byte_offset, joiner)
        when is_binary(rest) and is_integer(line) and is_integer(line_offset) and
               is_integer(byte_offset) do
-    {args |> Enum.join(joiner) |> List.wrap(), context}
+    {rest, args |> Enum.join(joiner) |> List.wrap(), context}
   end
 end
